@@ -59,11 +59,6 @@ RECONCILIATION = 'RECONCILIATION'
 
 MIN_TORCH_BACKEND_VERSION_SUPPORTED = '2.2.0'
 
-@dataclass
-class PipelineBulkupdateRequest:
-    dags: list()
-    dagruns: list()
-    tasks: list()
 
 @dataclass
 class TorchBuildVersion:
